@@ -1,15 +1,21 @@
 import logging
+import sys
 from typing import Callable, Coroutine, Dict, List, Optional
 from warnings import warn
 
-from dbus_next import Variant
-from typing_extensions import TypedDict, Literal
+from dbus_fast import Variant
+
+if sys.version_info[:2] < (3, 8):
+    from typing_extensions import Literal, TypedDict
+else:
+    from typing import Literal, TypedDict
 
 from ...exc import BleakError
 from ..device import BLEDevice
 from ..scanner import AdvertisementData, AdvertisementDataCallback, BaseBleakScanner
 from .advertisement_monitor import OrPatternLike
-from .manager import Device1, get_global_bluez_manager
+from .defs import Device1
+from .manager import get_global_bluez_manager
 
 logger = logging.getLogger(__name__)
 
@@ -69,11 +75,11 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
 
     def __init__(
         self,
-        detection_callback: Optional[AdvertisementDataCallback] = None,
-        service_uuids: Optional[List[str]] = None,
-        scanning_mode: Literal["active", "passive"] = "active",
+        detection_callback: Optional[AdvertisementDataCallback],
+        service_uuids: Optional[List[str]],
+        scanning_mode: Literal["active", "passive"],
         *,
-        bluez: BlueZScannerArgs = {},
+        bluez: BlueZScannerArgs,
         **kwargs,
     ):
         super(BleakScannerBlueZDBus, self).__init__(detection_callback, service_uuids)
@@ -81,8 +87,7 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
         self._scanning_mode = scanning_mode
 
         # kwarg "device" is for backwards compatibility
-        self._adapter = kwargs.get("adapter", kwargs.get("device", "hci0"))
-        self._adapter_path: str = f"/org/bluez/{self._adapter}"
+        self._adapter: Optional[str] = kwargs.get("adapter", kwargs.get("device"))
 
         # map of d-bus object path to d-bus object properties
         self._devices: Dict[str, Device1] = {}
@@ -127,15 +132,26 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
     async def start(self):
         manager = await get_global_bluez_manager()
 
+        if self._adapter:
+            adapter_path = f"/org/bluez/{self._adapter}"
+        else:
+            adapter_path = manager.get_default_adapter()
+
         self._devices.clear()
 
         if self._scanning_mode == "passive":
             self._stop = await manager.passive_scan(
-                self._adapter_path, self._or_patterns, self._handle_advertising_data
+                adapter_path,
+                self._or_patterns,
+                self._handle_advertising_data,
+                self._handle_device_removed,
             )
         else:
             self._stop = await manager.active_scan(
-                self._adapter_path, self._filters, self._handle_advertising_data
+                adapter_path,
+                self._filters,
+                self._handle_advertising_data,
+                self._handle_device_removed,
             )
 
     async def stop(self):
@@ -178,15 +194,9 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
 
     @property
     def discovered_devices(self) -> List[BLEDevice]:
-        # Reduce output.
         discovered_devices = []
-        for path, props in self._devices.items():
-            if not props:
-                logger.debug(
-                    "Disregarding %s since no properties could be obtained." % path
-                )
-                continue
 
+        for path, props in self._devices.items():
             uuids = props.get("UUIDs", [])
             manufacturer_data = props.get("ManufacturerData", {})
             discovered_devices.append(
@@ -225,6 +235,9 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
         _service_data = {k: bytes(v) for k, v in props.get("ServiceData", {}).items()}
         _service_uuids = props.get("UUIDs", [])
 
+        # Get tx power data
+        tx_power = props.get("TxPower")
+
         # Pack the advertisement data
         advertisement_data = AdvertisementData(
             local_name=_local_name,
@@ -232,6 +245,7 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
             service_data=_service_data,
             service_uuids=_service_uuids,
             platform_data=props,
+            tx_power=tx_power,
         )
 
         device = BLEDevice(
@@ -244,3 +258,15 @@ class BleakScannerBlueZDBus(BaseBleakScanner):
         )
 
         self._callback(device, advertisement_data)
+
+    def _handle_device_removed(self, device_path: str) -> None:
+        """
+        Handles a device being removed from BlueZ.
+        """
+        try:
+            del self._devices[device_path]
+        except KeyError:
+            # The device will not have been added to self._devices if no
+            # advertising data was received, so this is expected to happen
+            # occasionally.
+            pass
